package mockbrokerdriver

import (
	"query-service/internal/adapters/brokeradapter"
	"query-service/internal/drivers/brokerdriver"
)

// Driver is mock gateway
type Driver struct {
	gateway brokeradapter.GatewayInterface

	// Mock messages that are published by producers on this broker
	// Key is the routing key
	// Value is a slice of messages, in order of being sent 'first -> last'
	Messages map[string][]brokeradapter.Message
}

// CreateBroker creates a broker driver (mock)
func CreateBroker(gateway brokeradapter.GatewayInterface) *Driver {
	return &Driver{
		gateway:  gateway,
		Messages: make(map[string][]brokeradapter.Message),
	}
}

// CreateConsumer creates a consumer (mock)
func (d *Driver) CreateConsumer() brokerdriver.Consumer {
	return &Consumer{
		broker: d,
	}
}

// CreateProducer creates a producer (mock)
func (d *Driver) CreateProducer() brokerdriver.Producer {
	return &Producer{
		broker:   d,
		exchange: "ui-direct-exchange", // This is the only exchange this service produces to
	}
}
